# Changelog

## 0.1.0 (2025-03-10)

Full Changelog: [v0.1.0-alpha.2...v0.1.0](https://github.com/reductoai/reducto-python-sdk/compare/v0.1.0-alpha.2...v0.1.0)

### Features

* **api:** api update ([#10](https://github.com/reductoai/reducto-python-sdk/issues/10)) ([28ab6ce](https://github.com/reductoai/reducto-python-sdk/commit/28ab6cec5a1483f7bf4dbd56114f4e94d53c2224))
* **api:** api update ([#16](https://github.com/reductoai/reducto-python-sdk/issues/16)) ([902285c](https://github.com/reductoai/reducto-python-sdk/commit/902285ca3f6db52efe163020aef1c352ac32f52f))


### Chores

* **docs:** update client docstring ([#13](https://github.com/reductoai/reducto-python-sdk/issues/13)) ([d649e20](https://github.com/reductoai/reducto-python-sdk/commit/d649e204040395334f3fc0add66d7eaa2f28bc15))
* **internal:** remove unused http client options forwarding ([#14](https://github.com/reductoai/reducto-python-sdk/issues/14)) ([53cb68e](https://github.com/reductoai/reducto-python-sdk/commit/53cb68ecccda85d788bc27d6bee186c2b7fca75a))


### Documentation

* update URLs from stainlessapi.com to stainless.com ([#12](https://github.com/reductoai/reducto-python-sdk/issues/12)) ([ef54876](https://github.com/reductoai/reducto-python-sdk/commit/ef5487656b269f670bc5f119ebe87461dadf73f6))

## 0.1.0-alpha.2 (2025-02-27)

Full Changelog: [v0.1.0-alpha.1...v0.1.0-alpha.2](https://github.com/reductoai/reducto-python-sdk/compare/v0.1.0-alpha.1...v0.1.0-alpha.2)

### Features

* **api:** manual updates ([#7](https://github.com/reductoai/reducto-python-sdk/issues/7)) ([f0a3ac7](https://github.com/reductoai/reducto-python-sdk/commit/f0a3ac7feffd5ce250ca33795bf95fa4fb6a3481))
* **api:** update via SDK Studio ([#5](https://github.com/reductoai/reducto-python-sdk/issues/5)) ([5effb16](https://github.com/reductoai/reducto-python-sdk/commit/5effb162cbd6a44036fa87a612a0b66cb5314eab))


### Chores

* **internal:** properly set __pydantic_private__ ([#8](https://github.com/reductoai/reducto-python-sdk/issues/8)) ([38b3b62](https://github.com/reductoai/reducto-python-sdk/commit/38b3b62107a57a71f8299d164bc88199308198ed))

## 0.1.0-alpha.1 (2025-02-25)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/reductoai/reducto-python-sdk/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** update via SDK Studio ([db353a1](https://github.com/reductoai/reducto-python-sdk/commit/db353a1695d45a898a02b1ed30e60085dfa921f3))
* **api:** update via SDK Studio ([e891982](https://github.com/reductoai/reducto-python-sdk/commit/e891982d817ac48212fe76448809efdd23cf01c6))
* **api:** update via SDK Studio ([6429973](https://github.com/reductoai/reducto-python-sdk/commit/64299735c580254243b76094945ffa303817e66a))
* **api:** update via SDK Studio ([743f99b](https://github.com/reductoai/reducto-python-sdk/commit/743f99be8e673c3bb88ade34786eb648b1085b6a))
* **api:** update via SDK Studio ([40466be](https://github.com/reductoai/reducto-python-sdk/commit/40466be82533260118d825c022f7a02eb17c195b))
* **api:** update via SDK Studio ([ed0e969](https://github.com/reductoai/reducto-python-sdk/commit/ed0e969f59b734b3110c60c89a4a88cad816b735))
* **api:** update via SDK Studio ([a007184](https://github.com/reductoai/reducto-python-sdk/commit/a00718484793be2cf8be39970f4e0657ee512223))
* **api:** update via SDK Studio ([c444656](https://github.com/reductoai/reducto-python-sdk/commit/c444656862f8ba5e5a7fd9a5433b569e0903c095))


### Chores

* go live ([#1](https://github.com/reductoai/reducto-python-sdk/issues/1)) ([93f16d9](https://github.com/reductoai/reducto-python-sdk/commit/93f16d9397992fb0550baa288cec89d8d46b592d))
* update SDK settings ([#3](https://github.com/reductoai/reducto-python-sdk/issues/3)) ([9cc2125](https://github.com/reductoai/reducto-python-sdk/commit/9cc21254fdf5430aca69bcd987cc1653a0cee527))
